//
//  MCLShareConfig.h
//
//  An online version of the documentation can be found at https://docs.megacool.co
//
//  Do you feel like this reading docs? (╯°□°）╯︵ ┻━┻  Give us a shout if there's anything that's
//  unclear and we'll try to brighten the experience. We can sadly not replace flipped tables.
//


#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

#import "MCLShare.h"
#import "MCLConstants.h"

/**
 Pass this to `-[Megacool presentShareWithConfig:]` to configure how a share is performed.

 @note This class does not have atomic properties for efficiency, thus it's not thread-safe.
 */
@interface MCLShareConfig : NSObject <NSCopying>
NS_ASSUME_NONNULL_BEGIN

/**
 Which recording to share. Will use default if nil.
 */
@property(nonatomic, null_resettable, strong) NSString *recordingId;


/**
 Set the text to be shared on different channels. The user will
 usually have the ability to customize the message before sending.
 */
@property(nonatomic, strong) NSString *message;


/**
 A fallback to share if there are no frames in the given recording
 or something fails. Mutually exclusive with `fallbackImage.`
 */
@property(nonatomic, nullable, strong) NSURL *fallbackImageUrl;

/**
 A fallback to to share if there are no frames in the given recording
 or something fails. Mutually exclusive with `fallbackImageUrl.`
 */
@property(nonatomic, nullable, strong) UIImage *fallbackImage;

/**
 Customize the url included in the share to navigate to a specific section
 of your app.

 The link given here can be extracted from the link-clicked event on the receiving side.
 Note that only the path and query parameters will be respected. If set to f. ex
 `[NSURL URLWithString:@"/level2?difficulty=ludicruous"]`, the final url will
 end up as `https://mgcl.co/<your-app-identifier>/level2?difficulty=ludicruous&_m=<referral-code>`.
 */
@property(nonatomic, nullable, strong) NSURL *url;

/**
 Additional data to include with the share. This will be available to the receiver in the receivedShareOpened event.
 */
@property(nonatomic, nullable, strong) NSDictionary<NSString *, NSString *> *data;

/**
 On iPads, which view should present the popover.
 */
@property(nonatomic, nullable, strong) UIView *sourceView;

/**
 When using `shareToMessenger`, you can force to show the composer view instead of replying directly to a friend.
 More on Messenger's reply flow here: https://developers.facebook.com/docs/messenger/ios#handling_calls_messenger
 */
@property(nonatomic) BOOL messengerForceCompose;


/**
 Set sharing strategy.

 What type of data should be prioritized when sharing to channels
 that support @em either media @em or links.
 */
@property(nonatomic) MCLSharingStrategy strategy;


NS_ASSUME_NONNULL_END

@end
